@@ -522,7 +522,7 @@ static void setup_display_refresh_dropdown(CtkSLIMM *ctk_object)
         ctk_object->refresh_table_len = 0;
     }
     ctk_object->refresh_table =
-        (nvModeLinePtr *)calloc(ctk_object->num_modelines, sizeof(nvModeLinePtr));
+        calloc(ctk_object->num_modelines, sizeof(nvModeLinePtr));
     if (!ctk_object->refresh_table) {
         goto fail;
     }
@@ -694,8 +694,7 @@ static void setup_display_resolution_dropdown(CtkSLIMM *ctk_object)
         ctk_object->resolution_table_len = 0;
     }
     ctk_object->resolution_table =
-        (nvModeLinePtr *)calloc((ctk_object->num_modelines + 1),
-                                sizeof(nvModeLinePtr));
+        calloc((ctk_object->num_modelines + 1), sizeof(nvModeLinePtr));
     if (!ctk_object->resolution_table) {
         goto fail;
     }
@@ -859,7 +858,7 @@ static Bool parse_slimm_layout(CtkSLIMM *ctk_slimm,
                     gridConfigs[loc_idx].rows * gridConfigs[loc_idx].columns;
             }
         }
-        locs = (DpyLoc *)malloc(max_locs * sizeof(DpyLoc));
+        locs = malloc(max_locs * sizeof(DpyLoc));
         if (!locs) {
             err_msg = "Out of memory.";
             goto fail;
@@ -1150,8 +1149,8 @@ static Bool other_displays_have_modeline(nvLayoutPtr layout,
     nvGpuPtr gpu;
     nvDisplayPtr d;
 
-    for (gpu = layout->gpus; gpu; gpu = gpu->next) {
-        for (d = gpu->displays; d; d = d->next) {
+    for (gpu = layout->gpus; gpu; gpu = gpu->next_in_layout) {
+        for (d = gpu->displays; d; d = d->next_on_gpu) {
             if (display == d) continue;
             if (d->modelines == NULL) continue;
             if (!display_has_modeline(d, modeline)) {
@@ -1168,8 +1167,11 @@ static nvDisplayPtr find_active_display(nvLayoutPtr layout)
 {
     nvGpuPtr gpu;
     nvDisplayPtr display;
-    for (gpu = layout->gpus; gpu; gpu = gpu->next) {
-        for (display = gpu->displays; display; display = display->next) {
+
+    for (gpu = layout->gpus; gpu; gpu = gpu->next_in_layout) {
+        for (display = gpu->displays;
+             display;
+             display = display->next_on_gpu) {
             if (display->modelines) return display;
         }
     }
@@ -1339,7 +1341,7 @@ GtkWidget* ctk_slimm_new(NvCtrlAttributeHandle *handle,
         GridConfig *grid;
         int num_valid = 0;
 
-        for (gpu = layout->gpus; gpu; gpu = gpu->next) {
+        for (gpu = layout->gpus; gpu; gpu = gpu->next_in_layout) {
             num_displays += gpu->num_displays;
         }
 
